{ pkgs,
...
}:

let 
in {
  programs.home-manager.enable = true;
  programs.home-manager.path = https://github.com/rycee/home-manager/archive/master.tar.gz;

  nixpkgs.config = {
    allowBroken = true;
    allowUnfree = true;

    # TODO: move this to a pkgs overlay
    packageOverrides = pkgs: with pkgs; {
      busyboxStatic =  busybox.override {
        enableStatic = true;
        extraConfig = ''
           CONFIG_STATIC y
           CONFIG_INSTALL_APPLET_DONT y
           CONFIG_INSTALL_APPLET_SYMLINKS n
         '';
      };

      dropbearStatic = dropbear.override {
        enableStatic = true;
      };

      just = pkgs.callPackage ../../pkgs/just.nix {};
    };
  };

  home.keyboard = {
    layout = "us";
    variant = "altgr-intl";
    options = [ 
      "nodeadkeys"
     # "caps:swapescape"
    ];
  };

  programs.direnv.enable = true;

  home.sessionVariables = {
    NIXPKGS_ALLOW_UNFREE = "1";
    # Don't create .pyc files.
    PYTHONDONTWRITEBYTECODE = "1";
  };

  programs.command-not-found.enable = true;
  programs.fzf.enable = true;

  home.packages =
    [] ++ (with pkgs; [
      # git helpers
      git-crypt

      vcsh
      # Authentication
      cacert
      openssl
      mkpasswd

      just
      ]);
}
